@@ -12,43 +12,43 @@ use namespace::autoclean;
 use Firewall::Utils::Date;
 use Firewall::Policy::Searcher::Report::FwInfo;
 
-has dbi => ( is => 'ro', does => 'Firewall::DBI::Role', required => 1, );
+has dbi => (is => 'ro', does => 'Firewall::DBI::Role', required => 1,);
 
-has searcherReportFwInfo => ( is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1, );
+has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1,);
 
-has commandText => ( is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] }, );
+has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
 sub addToCommandText {
-  my ( $self, @commands ) = @_;
+  my ($self, @commands) = @_;
   push @{$self->commandText}, @commands;
 }
 
 sub design {
   my $self = shift;
-  if ( $self->searcherReportFwInfo->type eq 'new' ) {
+  if ($self->searcherReportFwInfo->type eq 'new') {
     $self->createRule;
   }
-  elsif ( $self->searcherReportFwInfo->type eq 'modify' ) {
+  elsif ($self->searcherReportFwInfo->type eq 'modify') {
     $self->modifyRule;
   }
-  elsif ( $self->searcherReportFwInfo->type eq 'ignore' ) {
-    if ( defined $self->searcherReportFwInfo->action ) {
+  elsif ($self->searcherReportFwInfo->type eq 'ignore') {
+    if (defined $self->searcherReportFwInfo->action) {
       my $param = $self->searcherReportFwInfo->action->{'new'};
-      for my $type ( keys %{$param} ) {
-        if ( $type eq 'natDst' or $type eq 'natSrc' ) {
-          $self->createNat( $param->{$type} );
+      for my $type (keys %{$param}) {
+        if ($type eq 'natDst' or $type eq 'natSrc') {
+          $self->createNat($param->{$type});
         }
       }
     }
   }
   else {
-    confess( "ERROR: searcherReportFwInfo->type(" . $self->searcherReportFwInfo->type . ") must be 'new' or 'modify'" );
+    confess("ERROR: searcherReportFwInfo->type(" . $self->searcherReportFwInfo->type . ") must be 'new' or 'modify'");
   }
-  if ( @{$self->commandText} > 0 ) {
+  if (@{$self->commandText} > 0) {
     push @{$self->commandText}, 'commit check';
     push @{$self->commandText}, 'commit';
   }
-  return join( '', map {"$_\n"} @{$self->commandText} );
+  return join('', map {"$_\n"} @{$self->commandText});
 } ## end sub design
 
 sub createRule {
@@ -56,7 +56,7 @@ sub createRule {
 
   #先检查涉及到的 addr or srv 在防火墙上有没有已经存在的名字，没有就需要创建
   my $action  = $self->searcherReportFwInfo->action;
-  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat( $action->{'new'} );
+  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($action->{'new'});
 
 =example
 set security policies from-zone l2-untrust to-zone l2-trust policy p409 match source-address host_10.39.100.252
@@ -66,11 +66,11 @@ set security policies from-zone l2-untrust to-zone l2-trust policy p409 then per
 
 =cut
 
-  my ( $fromZone, $toZone ) = ( $self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone );
+  my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
   my @commands;
-  my $randNum  = $$ || sprintf( '%05d', int( rand(99999) ) );
+  my $randNum  = $$ || sprintf('%05d', int(rand(99999)));
   my $ruleName = 'p_' . Firewall::Utils::Date->new->getFormatedDate('yyyymmdd_hhmiss') . "_$randNum";
-  for my $type ( keys %{$nameMap} ) {
+  for my $type (keys %{$nameMap}) {
     push @commands,
       map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match source-address $_"}
       @{$nameMap->{$type}}
@@ -80,8 +80,7 @@ set security policies from-zone l2-untrust to-zone l2-trust policy p409 then per
       @{$nameMap->{$type}}
       if $type eq 'dst';
     push @commands,
-      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"}
-      @{$nameMap->{$type}}
+      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"} @{$nameMap->{$type}}
       if $type eq 'srv';
   }
   push @commands, "set security policies from-zone $fromZone to-zone $toZone policy $ruleName then permit";
@@ -92,15 +91,15 @@ sub modifyRule {
   my $self = shift;
 
   #先检查涉及到的 addr or srv 在防火墙上有没有已经存在的名字，没有就需要创建
-  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat( $self->searcherReportFwInfo->action->{'add'} );
-  if ( $self->searcherReportFwInfo->action->{'new'} ) {
-    $self->checkAndCreateAddrOrSrvOrNat( $self->searcherReportFwInfo->action->{'new'} );
+  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{'add'});
+  if ($self->searcherReportFwInfo->action->{'new'}) {
+    $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{'new'});
   }
-  my ( $fromZone, $toZone ) = ( $self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone );
+  my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
   my $ruleName = $self->searcherReportFwInfo->ruleObj->ruleName;
 
   my @commands;
-  for my $type ( keys %{$nameMap} ) {
+  for my $type (keys %{$nameMap}) {
     push @commands,
       map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match source-address $_"}
       @{$nameMap->{$type}}
@@ -110,8 +109,7 @@ sub modifyRule {
       @{$nameMap->{$type}}
       if $type eq 'dst';
     push @commands,
-      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"}
-      @{$nameMap->{$type}}
+      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"} @{$nameMap->{$type}}
       if $type eq 'srv';
   }
 
@@ -120,16 +118,16 @@ sub modifyRule {
 } ## end sub modifyRule
 
 sub checkAndCreateAddrOrSrvOrNat {
-  my ( $self, $param ) = @_;
+  my ($self, $param) = @_;
   my $nameMap;
-  for my $type ( keys %{$param} ) {
-    if ( $type eq 'natDst' or $type eq 'natSrc' ) {
-      $self->createNat( $param->{$type}, $type );
+  for my $type (keys %{$param}) {
+    if ($type eq 'natDst' or $type eq 'natSrc') {
+      $self->createNat($param->{$type}, $type);
     }
     else {
-      for my $addrOrSrv ( keys %{$param->{$type}} ) {
-        if ( not defined $param->{$type}{$addrOrSrv} ) {
-          my $func = "create" . ( ucfirst $type );    #createSrc, createDst, createSrv
+      for my $addrOrSrv (keys %{$param->{$type}}) {
+        if (not defined $param->{$type}{$addrOrSrv}) {
+          my $func = "create" . (ucfirst $type);    #createSrc, createDst, createSrv
           push @{$nameMap->{$type}}, $self->$func($addrOrSrv);
         }
         else {
@@ -142,33 +140,33 @@ sub checkAndCreateAddrOrSrvOrNat {
 } ## end sub checkAndCreateAddrOrSrvOrNat
 
 sub createNat {
-  my ( $self, $param, $type ) = @_;
+  my ($self, $param, $type) = @_;
   my $dyNatInfo = {};
-  for my $natInfo ( values %{$param} ) {
-    if ( $natInfo->{natInfo}->{natType} eq 'static' ) {
+  for my $natInfo (values %{$param}) {
+    if ($natInfo->{natInfo}->{natType} eq 'static') {
       $self->createStaticNat($natInfo);
     }
     else {
       $dyNatInfo->{$type}{$natInfo->{natInfo}}{$natInfo->{realIp}} = $natInfo;
     }
   }
-  if ( scalar( values %{$dyNatInfo} ) != 0 ) {
+  if (scalar(values %{$dyNatInfo}) != 0) {
     $self->createDyNat($dyNatInfo);
   }
 }
 
 sub createStaticNat {
-  my ( $self, $natInfo ) = @_;
+  my ($self, $natInfo) = @_;
 
   #set security nat static rule-set dmz_static_nat rule host_172_29_16_1 match destination-address 172.29.16.1/32
   #set security nat static rule-set dmz_static_nat rule host_172_29_16_1 then static-nat prefix 10.11.100.97/32
 
-  my $natName = 'host_' . join( '_', ( split( /[\.\/]/, $natInfo->{natInfo}{natIp} ) )[ 0, 1, 2, 3 ] );
+  my $natName = 'host_' . join('_', (split(/[\.\/]/, $natInfo->{natInfo}{natIp}))[0, 1, 2, 3]);
   my @commands;
   my $realIp  = $natInfo->{realIp};
   my $ruleSet = $natInfo->{ruleSet};
   my $natIp   = $natInfo->{natInfo}{natIp};
-  if ( defined $ruleSet ) {
+  if (defined $ruleSet) {
     push @commands, "set security nat static rule-set $ruleSet rule $natName match destination-address $natIp";
     push @commands, "set security nat static rule-set $ruleSet rule $natName then static-nat prefix $realIp";
     $self->addToCommandText(@commands);
@@ -205,63 +203,62 @@ set security nat destination rule-set untrust_dmz rule rule23 then destination-n
 =cut
 
 sub createDyNat {
-  my ( $self, $param ) = @_;
+  my ($self, $param) = @_;
   my @commands;
-  my ( $fromZone, $toZone ) = ( $self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone );
+  my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
   my $srvMap = $self->searcherReportFwInfo->srvMap;
-  for my $type ( keys %{$param} ) {
-    for my $natIps ( values %{$param->{$type}} ) {
-      my ( $natDirection, $ruleSet, $ruleName, $poolName, $natInfo );
+  for my $type (keys %{$param}) {
+    for my $natIps (values %{$param->{$type}}) {
+      my ($natDirection, $ruleSet, $ruleName, $poolName, $natInfo);
       $natDirection = 'source'      if $type eq 'natSrc';
       $natDirection = 'destination' if $type eq 'natDst';
-      $natInfo      = ( values %{$natIps} )[0]->{natInfo};
-      $ruleSet      = ( values %{$natIps} )[0]->{ruleSet};
-      my $randNum = sprintf( '%05d', int( rand(99999) ) );
+      $natInfo      = (values %{$natIps})[0]->{natInfo};
+      $ruleSet      = (values %{$natIps})[0]->{ruleSet};
+      my $randNum = sprintf('%05d', int(rand(99999)));
       $ruleName = "rule_$randNum";
-      if ( not defined $ruleSet ) {
+      if (not defined $ruleSet) {
         $ruleSet = $fromZone . '_' . $toZone;
         push @commands, "set security nat $natDirection rule-set $ruleSet from zone $fromZone";
         push @commands, "set security nat $natDirection rule-set $ruleSet to zone $toZone";
 
       }
       else {
-        while ( defined $self->searcherReportFwInfo->parser->getDynamicNat( $ruleSet, $ruleName ) ) {
-          $randNum  = sprintf( '%05d', int( rand(99999) ) );
+        while (defined $self->searcherReportFwInfo->parser->getDynamicNat($ruleSet, $ruleName)) {
+          $randNum  = sprintf('%05d', int(rand(99999)));
           $ruleName = "rule_$randNum";
         }
       }
 
-      if ( $type eq 'natSrc' ) {
-        $poolName = $self->getOrCreatePool( $type, $natIps );
-        for my $natIp ( keys %{$natIps} ) {
+      if ($type eq 'natSrc') {
+        $poolName = $self->getOrCreatePool($type, $natIps);
+        for my $natIp (keys %{$natIps}) {
           push @commands, "set security nat source rule-set $ruleSet rule $ruleName match source-address $natIp";
 
         }
-        if ( defined $natInfo->{natOption} and $natInfo->{natOption} =~ /d/ ) {
-          for my $dstIp ( keys %{$self->searcherReportFwInfo->dstMap} ) {
+        if (defined $natInfo->{natOption} and $natInfo->{natOption} =~ /d/) {
+          for my $dstIp (keys %{$self->searcherReportFwInfo->dstMap}) {
             push @commands, "set security nat source rule-set $ruleSet rule $ruleName match destination-address $dstIp"
               if $dstIp ne '0.0.0.0/0';
           }
         }
         push @commands, "set security nat source rule-set $ruleSet rule $ruleName then source-nat $poolName";
       }
-      elsif ( $type eq 'natDst' ) {
+      elsif ($type eq 'natDst') {
 
         #需要做端口NAT，可能存在多端口情况，每个端口都需要一套NAT策略
-        if ( defined $natInfo->{natOption} and $natInfo->{natOption} =~ /p/ ) {
-          for my $portInfo ( values %{$self->searcherReportFwInfo->srvMap} ) {
-            $poolName = $self->getOrCreatePool( $type, $natIps, $portInfo );
-            $randNum  = sprintf( '%05d', int( rand(99999) ) );
+        if (defined $natInfo->{natOption} and $natInfo->{natOption} =~ /p/) {
+          for my $portInfo (values %{$self->searcherReportFwInfo->srvMap}) {
+            $poolName = $self->getOrCreatePool($type, $natIps, $portInfo);
+            $randNum  = sprintf('%05d', int(rand(99999)));
             $ruleName = "rule_$randNum";
-            while ( defined $self->searcherReportFwInfo->parser->getDynamicNat( $ruleSet, $ruleName ) ) {
-              $randNum  = sprintf( '%05d', int( rand(99999) ) );
+            while (defined $self->searcherReportFwInfo->parser->getDynamicNat($ruleSet, $ruleName)) {
+              $randNum  = sprintf('%05d', int(rand(99999)));
               $ruleName = "rule_$randNum";
             }
 
-            if ( defined $natInfo->{natOption} and $natInfo->{natOption} =~ /s/ ) {
-              for my $srcIp ( keys %{$self->searcherReportFwInfo->srcMap} ) {
-                push @commands,
-                  "set security nat destination rule-set $ruleSet rule $ruleName match source-address $srcIp"
+            if (defined $natInfo->{natOption} and $natInfo->{natOption} =~ /s/) {
+              for my $srcIp (keys %{$self->searcherReportFwInfo->srcMap}) {
+                push @commands, "set security nat destination rule-set $ruleSet rule $ruleName match source-address $srcIp"
                   if $srcIp ne '0.0.0.0/0';
               }
             }
@@ -269,33 +266,29 @@ sub createDyNat {
               "set security nat destination rule-set $ruleSet rule $ruleName match destination-address $natInfo->{natIp}";
             my $natPort = $portInfo->{origin};
             $natPort = $portInfo->{natPort} if defined $portInfo->{natPort};
-            my ( $pro, $port ) = split( '/', $natPort );
-            push @commands,
-              "set security nat destination rule-set $ruleSet rule $ruleName match destination-port $port";
-            push @commands,
-              "set security nat destination rule-set $ruleSet rule $ruleName then destination-nat $poolName";
+            my ($pro, $port) = split('/', $natPort);
+            push @commands, "set security nat destination rule-set $ruleSet rule $ruleName match destination-port $port";
+            push @commands, "set security nat destination rule-set $ruleSet rule $ruleName then destination-nat $poolName";
           } ## end for my $portInfo ( values...)
         }
         else {
-          $poolName = $self->getOrCreatePool( $type, $natIps );
-          $randNum  = sprintf( '%05d', int( rand(99999) ) );
+          $poolName = $self->getOrCreatePool($type, $natIps);
+          $randNum  = sprintf('%05d', int(rand(99999)));
           $ruleName = "rule_$randNum";
-          while ( defined $self->searcherReportFwInfo->parser->getDynamicNat( $ruleSet, $ruleName ) ) {
-            $randNum  = sprintf( '%05d', int( rand(99999) ) );
+          while (defined $self->searcherReportFwInfo->parser->getDynamicNat($ruleSet, $ruleName)) {
+            $randNum  = sprintf('%05d', int(rand(99999)));
             $ruleName = "rule_$randNum";
           }
 
-          if ( defined $natInfo->{natOption} and $natInfo->{natOption} =~ /s/ ) {
-            for my $srcIp ( keys %{$self->searcherReportFwInfo->srcMap} ) {
-              push @commands,
-                "set security nat destination rule-set $ruleSet rule $ruleName match source-address $srcIp"
+          if (defined $natInfo->{natOption} and $natInfo->{natOption} =~ /s/) {
+            for my $srcIp (keys %{$self->searcherReportFwInfo->srcMap}) {
+              push @commands, "set security nat destination rule-set $ruleSet rule $ruleName match source-address $srcIp"
                 if $srcIp ne '0.0.0.0/0';
             }
           }
           push @commands,
             "set security nat destination rule-set $ruleSet rule $ruleName match destination-address $natInfo->{natIp}";
-          push @commands,
-            "set security nat destination rule-set $ruleSet rule $ruleName then destination-nat $poolName";
+          push @commands, "set security nat destination rule-set $ruleSet rule $ruleName then destination-nat $poolName";
 
         } ## end else [ if ( defined $natInfo->...)]
 
@@ -308,12 +301,12 @@ sub createDyNat {
 } ## end sub createDyNat
 
 sub getOrCreatePool {
-  my ( $self, $type, $natIps, $portInfo ) = @_;
+  my ($self, $type, $natIps, $portInfo) = @_;
   my $poolName;
-  my $natInfo = ( values %{$natIps} )[0]->{natInfo};
+  my $natInfo = (values %{$natIps})[0]->{natInfo};
   my $poolIp;
-  if ( $type eq 'natSrc' ) {
-    if ( defined $natInfo->{natIp} ) {
+  if ($type eq 'natSrc') {
+    if (defined $natInfo->{natIp}) {
       $poolIp = $natInfo->{natIp};
     }
     else {
@@ -324,37 +317,37 @@ sub getOrCreatePool {
   $poolIp = $natInfo->{natIp} if $type eq 'natSrc';
   my $natPools = $self->searcherReportFwInfo->parser->elements->natPool;
 
-  #say dumper $self->searcherReportFwInfo->srvMap;exit;
-  $poolIp = $natInfo->{natIp}                  if $type eq 'natSrc';
-  $poolIp = ( values %{$natIps} )[0]->{realIp} if $type eq 'natDst';
+  #print dumper $self->searcherReportFwInfo->srvMap;exit;
+  $poolIp = $natInfo->{natIp}                if $type eq 'natSrc';
+  $poolIp = (values %{$natIps})[0]->{realIp} if $type eq 'natDst';
   $poolIp =~ s/$/\/32/ if $poolIp !~ /\//;
-  my ( $ip, $mask ) = split( '/', $poolIp );
-  my $poolRange = Firewall::Utils::Ip->new->getRangeFromIpMask( $ip, $mask );
+  my ($ip, $mask) = split('/', $poolIp);
+  my $poolRange = Firewall::Utils::Ip->new->getRangeFromIpMask($ip, $mask);
   my @commands;
-  if ( $type eq 'natSrc' ) {
+  if ($type eq 'natSrc') {
 
-    for my $pool ( values %{$natPools} ) {
-      if ( $pool->natDirection eq 'source' and $pool->poolRange->isEqual($poolRange) ) {
+    for my $pool (values %{$natPools}) {
+      if ($pool->natDirection eq 'source' and $pool->poolRange->isEqual($poolRange)) {
         return "pool " . $pool->poolName;
       }
     }
 
     #没找到已有pool,新建
     # set security nat source pool srcnat_pool_3 address 202.69.21.46/32 to 202.69.21.46/32
-    my $randNum = sprintf( '%05d', int( rand(99999) ) );
+    my $randNum = sprintf('%05d', int(rand(99999)));
     $poolName = "srcnat_pool_$randNum";
-    while ( defined $self->searcherReportFwInfo->parser->getNatPool($poolName) ) {
-      $randNum  = sprintf( '%05d', int( rand(99999) ) );
+    while (defined $self->searcherReportFwInfo->parser->getNatPool($poolName)) {
+      $randNum  = sprintf('%05d', int(rand(99999)));
       $poolName = "srcnat_pool_$randNum";
     }
     push @commands, "set security nat source pool $poolName address $poolIp to $poolIp";
 
   }
-  elsif ( $type eq 'natDst' ) {
-    for my $pool ( values %{$natPools} ) {
-      if ( $pool->natDirection eq 'destination' and $pool->poolRange->isEqual($poolRange) ) {
-        if ( defined $portInfo ) {
-          if ( defined $pool->poolPort and $pool->poolPort eq $portInfo->{origin} ) {
+  elsif ($type eq 'natDst') {
+    for my $pool (values %{$natPools}) {
+      if ($pool->natDirection eq 'destination' and $pool->poolRange->isEqual($poolRange)) {
+        if (defined $portInfo) {
+          if (defined $pool->poolPort and $pool->poolPort eq $portInfo->{origin}) {
             return "pool " . $pool->poolName;
           }
         }
@@ -367,15 +360,15 @@ sub getOrCreatePool {
     #没有找到pool,需要新建
     #set security nat destination pool dstnat_pool_23 address 172.28.32.75/32
     #set security nat destination pool dstnat_pool_23 address port 80
-    my $randNum = sprintf( '%05d', int( rand(99999) ) );
+    my $randNum = sprintf('%05d', int(rand(99999)));
     $poolName = "dstnat_pool_$randNum";
-    while ( defined $self->searcherReportFwInfo->parser->getNatPool($poolName) ) {
-      $randNum  = sprintf( '%05d', int( rand(99999) ) );
+    while (defined $self->searcherReportFwInfo->parser->getNatPool($poolName)) {
+      $randNum  = sprintf('%05d', int(rand(99999)));
       $poolName = "dstnat_pool_$randNum";
     }
     push @commands, "set security nat destination pool $poolName address $poolIp";
-    if ( defined $portInfo ) {
-      my ( $pro, $port ) = split( '/', $portInfo->{origin} );
+    if (defined $portInfo) {
+      my ($pro, $port) = split('/', $portInfo->{origin});
       push @commands, "set security nat destination pool $poolName address port $port";
     }
 
@@ -385,56 +378,54 @@ sub getOrCreatePool {
 } ## end sub getOrCreatePool
 
 sub createSrc {
-  my ( $self, $addr ) = @_;
-  return $self->createAddress( $self->searcherReportFwInfo->fromZone, $addr );
+  my ($self, $addr) = @_;
+  return $self->createAddress($self->searcherReportFwInfo->fromZone, $addr);
 }
 
 sub createDst {
-  my ( $self, $addr ) = @_;
-  return $self->createAddress( $self->searcherReportFwInfo->toZone, $addr );
+  my ($self, $addr) = @_;
+  return $self->createAddress($self->searcherReportFwInfo->toZone, $addr);
 }
 
 sub createSrv {
-  my ( $self, $srv ) = @_;
+  my ($self, $srv) = @_;
   return $self->createService($srv);
 }
 
 sub createAddress {
-  my ( $self, $zoneName, $addr ) = @_;
+  my ($self, $zoneName, $addr) = @_;
 
   #set security zones security-zone l2-untrust address-book address host_10.35.194.90 10.35.194.90/32
-  my ( $ip, $mask ) = split( '/', $addr );
-  my ( $addressName, $ipString, $ipMin, $ipMax );
-  if ( not defined $mask ) {
-    if ( $ip =~ /(\d+\.)(\d+\.)(\d+\.)(\d+)-(\d+)/ ) {
-      ( $ipMin, $ipMax ) = ( $1 . $2 . $3 . $4, $1 . $2 . $3 . $5 );
+  my ($ip, $mask) = split('/', $addr);
+  my ($addressName, $ipString, $ipMin, $ipMax);
+  if (not defined $mask) {
+    if ($ip =~ /(\d+\.)(\d+\.)(\d+\.)(\d+)-(\d+)/) {
+      ($ipMin, $ipMax) = ($1 . $2 . $3 . $4, $1 . $2 . $3 . $5);
       $addressName = "Range_$ip";
     }
 
   }
-  elsif ( $mask == 32 ) {
+  elsif ($mask == 32) {
     $ipString    = $ip;
     $addressName = "Host_$ip";
   }
-  elsif ( $mask == 0 ) {
+  elsif ($mask == 0) {
     return 'any';
   }
   else {
-    $ipString    = Firewall::Utils::Ip->new->getNetIpFromIpMask( $ip, $mask );
+    $ipString    = Firewall::Utils::Ip->new->getNetIpFromIpMask($ip, $mask);
     $addressName = "Net_$ipString/$mask";
   }
 
-  my $command = "set security zones security-zone $zoneName address-book address $addressName $ipString/$mask"
-    if defined $mask;
-  $command
-    = "set security zones security-zone $zoneName address-book address $addressName range-address $ipMin to $ipMax"
+  my $command = "set security zones security-zone $zoneName address-book address $addressName $ipString/$mask" if defined $mask;
+  $command = "set security zones security-zone $zoneName address-book address $addressName range-address $ipMin to $ipMax"
     if defined $ipMin;
   $self->addToCommandText($command);
   return $addressName;
 } ## end sub createAddress
 
 sub createService {
-  my ( $self, $srv ) = @_;
+  my ($self, $srv) = @_;
 
 =services
 set applications application tcp_8080 term tcp_8080 protocol tcp
@@ -442,16 +433,16 @@ set applications application tcp_8080 term tcp_8080 source-port 0-65535
 set applications application tcp_8080 term tcp_8080 destination-port 8080-8080
 =cut
 
-  my ( $protocol, $port ) = split( '/', $srv );
+  my ($protocol, $port) = split('/', $srv);
   $protocol = lc $protocol;
   return if $protocol ne 'tcp' and $protocol ne 'udp';
 
-  my ( $serviceName, $dstPort );
-  if ( $port =~ /^(?<portMin>\d+)\-(?<portMax>\d+)$/o ) {
+  my ($serviceName, $dstPort);
+  if ($port =~ /^(?<portMin>\d+)\-(?<portMax>\d+)$/o) {
     $serviceName = uc($protocol) . "_" . $+{portMin} . "-" . $+{portMax};
     $dstPort     = $+{portMin} . "-" . $+{portMax};
   }
-  elsif ( $port =~ /^\d+$/o ) {
+  elsif ($port =~ /^\d+$/o) {
     $serviceName = uc($protocol) . "_" . $port;
     $dstPort     = $port . "-" . $port;
   }
