@@ -19,17 +19,17 @@ use Firewall::Policy::Searcher::Report::FwInfo;
 #------------------------------------------------------------------------------
 # Firewall::Policy::Designer::Topsec 通用属性
 #------------------------------------------------------------------------------
-has dbi => ( is => 'ro', does => 'Firewall::DBI::Role', required => 1, );
+has dbi => (is => 'ro', does => 'Firewall::DBI::Role', required => 1,);
 
-has searcherReportFwInfo => ( is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1, );
+has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1,);
 
-has commandText => ( is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] }, );
+has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
 #------------------------------------------------------------------------------
 # addToCommandText 设置 commandText 属性，入参为标量
 #------------------------------------------------------------------------------
 sub addToCommandText {
-  my ( $self, $commands ) = @_;
+  my ($self, $commands) = @_;
   push @{$self->{"commandText"}}, $commands;
 }
 
@@ -44,34 +44,32 @@ sub design {
   my $action = $self->{"searcherReportFwInfo"}{"action"};
 
   # 情况1：当类型为 new，则新建策略
-  if ( $type eq 'new' ) {
+  if ($type eq 'new') {
     $self->createRule();
   }
 
   # 情况2：当类型为 modify，则修改策略
-  elsif ( $type eq 'modify' ) {
+  elsif ($type eq 'modify') {
     $self->modifyRule();
   }
 
   # 情况3：当类型为 ignore，还需要检查是否存在 NAT 策略
-  elsif ( $type eq 'ignore' ) {
+  elsif ($type eq 'ignore') {
     my $param = $action->{"new"} if defined $action;
-    for my $natDirection ( keys %{$param} ) {
-      if ( $natDirection eq 'natSrc' || $natDirection eq 'natDst' ) {
-        $self->createNat( $param->{$natDirection}, $type );
+    for my $natDirection (keys %{$param}) {
+      if ($natDirection eq 'natSrc' || $natDirection eq 'natDst') {
+        $self->createNat($param->{$natDirection}, $type);
       }
     }
   }
 
   # 其他情况：抛出异常，定位排除
   else {
-    confess "ERROR: searcherReportFwInfo->type("
-      . $self->{"searcherReportFwInfo"}{"type"}
-      . ") must be 'new' or 'modify'";
+    confess "ERROR: searcherReportFwInfo->type(" . $self->{"searcherReportFwInfo"}{"type"} . ") must be 'new' or 'modify'";
   }
 
   # 拼接数组为字符串并返回
-  return join( "\n", uniq @{$self->{"commandText"}} );
+  return join("\n", uniq @{$self->{"commandText"}});
 } ## end sub design
 
 #------------------------------------------------------------------------------
@@ -84,25 +82,24 @@ sub createRule {
   my $create = $self->{"searcherReportFwInfo"}{"action"}{"new"};
 
   # 获取源目安全区并拼接
-  my ( $fromZone, $toZone )
-    = ( $self->{"searcherReportFwInfo"}{"fromZone"}, $self->{"searcherReportFwInfo"}{"toZone"} );
+  my ($fromZone, $toZone) = ($self->{"searcherReportFwInfo"}{"fromZone"}, $self->{"searcherReportFwInfo"}{"toZone"});
 
   #my $zoneStr = ( $fromZone and $toZone ) ? "srcarea '$fromZone ' dstarea '$toZone '" : '';
   my $zoneStr = '';
 
   # 根据策略查询结果进行命令拼接
-  my ( $srcStr, $dstStr, $srvStr );
+  my ($srcStr, $dstStr, $srvStr);
   my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($create);
 
   # 遍历 addrOrSrvMap
-  for my $addrOrSrv ( keys %{$nameMap} ) {
+  for my $addrOrSrv (keys %{$nameMap}) {
 
     # 情况1：当类型为 src，依次取出判断
-    if ( $addrOrSrv eq 'src' ) {
+    if ($addrOrSrv eq 'src') {
 
       # srcStr 前后需要使用 ''
       $srcStr = "src '";
-      for my $host ( @{$nameMap->{$addrOrSrv}} ) {
+      for my $host (@{$nameMap->{$addrOrSrv}}) {
         $srcStr .= $host . " ";
       }
 
@@ -111,11 +108,11 @@ sub createRule {
     }
 
     # 情况2：当类型为 dst，依次取出判断
-    elsif ( $addrOrSrv eq 'dst' ) {
+    elsif ($addrOrSrv eq 'dst') {
 
       # dstStr 前后需要使用 ''
       $dstStr = "dst '";
-      for my $host ( @{$nameMap->{$addrOrSrv}} ) {
+      for my $host (@{$nameMap->{$addrOrSrv}}) {
         $dstStr .= $host . " ";
       }
 
@@ -125,11 +122,11 @@ sub createRule {
     }
 
     # 情况3：当类型为 src，依次取出判断
-    elsif ( $addrOrSrv eq 'srv' ) {
+    elsif ($addrOrSrv eq 'srv') {
 
       # srvStr 前后需要使用 ''
       $srvStr = "service '";
-      for my $srv ( @{$nameMap->{$addrOrSrv}} ) {
+      for my $srv (@{$nameMap->{$addrOrSrv}}) {
         $srvStr .= $srv . " ";
       }
 
@@ -158,44 +155,44 @@ sub modifyRule {
 
   # 可能已开通访问控制但缺少 NAT 转换
   my $action = $self->{"searcherReportFwInfo"}{"action"}{"new"};
-  if ( defined $action ) {
-    for my $natDirection ( keys %{$action} ) {
-      if ( $natDirection eq 'natDst' or $natDirection eq 'natSrc' ) {
-        $self->createNat( $action->{$natDirection}, $natDirection );
+  if (defined $action) {
+    for my $natDirection (keys %{$action}) {
+      if ($natDirection eq 'natDst' or $natDirection eq 'natSrc') {
+        $self->createNat($action->{$natDirection}, $natDirection);
       }
     }
   }
 
   # 遍历 addrOrSrvMap
-  my ( $srcMem, $dstMem, $srvMem );
+  my ($srcMem, $dstMem, $srvMem);
   my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($modify);
-  for my $addrOrSrv ( keys %{$nameMap} ) {
+  for my $addrOrSrv (keys %{$nameMap}) {
 
     # 情况1：源地址
-    if ( $addrOrSrv eq 'src' ) {
+    if ($addrOrSrv eq 'src') {
       $content =~ /src\s+'(?<src>.+?)'/mi;
       my $srcStr = $+{"src"};
-      for my $host ( @{$nameMap->{$addrOrSrv}} ) {
+      for my $host (@{$nameMap->{$addrOrSrv}}) {
         $srcStr .= $host . " ";
       }
       $srcMem .= "src ' $srcStr' ";
     }
 
     # 情况2：目的地址
-    elsif ( $addrOrSrv eq 'dst' ) {
+    elsif ($addrOrSrv eq 'dst') {
       $content =~ /dst\s+'(?<dst>.+?)'/mi;
       my $dstStr = $+{"dst"};
-      for my $host ( @{$nameMap->{$addrOrSrv}} ) {
+      for my $host (@{$nameMap->{$addrOrSrv}}) {
         $dstStr .= $host . " ";
       }
       $dstMem .= "dst ' $dstStr' ";
     }
 
     # 情况3：服务端口
-    elsif ( $addrOrSrv eq 'srv' ) {
+    elsif ($addrOrSrv eq 'srv') {
       $content =~ /service\s+'(?<srv>.+?)'/mi;
       my $srvStr = $+{"srv"};
-      for my $srv ( @{$nameMap->{$addrOrSrv}} ) {
+      for my $srv (@{$nameMap->{$addrOrSrv}}) {
         $srvStr .= $srv . " ";
       }
       $srvMem .= "service ' $srvStr' ";
@@ -209,26 +206,26 @@ sub modifyRule {
 # checkAndCreateAddrOrSrvOrNat 创建地址、服务端口或NAT
 #------------------------------------------------------------------------------
 sub checkAndCreateAddrOrSrvOrNat {
-  my ( $self, $param ) = @_;
+  my ($self, $param) = @_;
 
   # 初始化 nameMap 标量
   my $nameMap;
 
   # 遍历 param
-  for my $type ( keys %{$param} ) {
+  for my $type (keys %{$param}) {
 
     # 情况1： nat 转换
-    if ( $type eq 'natDst' or $type eq 'natSrc' ) {
-      $nameMap->{$type} = $self->createNat( $param->{$type}, $type );
+    if ($type eq 'natDst' or $type eq 'natSrc') {
+      $nameMap->{$type} = $self->createNat($param->{$type}, $type);
     }
 
     # 情况2：addrOrSrv 配置
-    elsif ( $type ne 'natDst' and $type ne 'natSrc' ) {
-      for my $addrOrSrv ( keys %{$param->{$type}} ) {
+    elsif ($type ne 'natDst' and $type ne 'natSrc') {
+      for my $addrOrSrv (keys %{$param->{$type}}) {
 
         # 情况2.1：未定义则新增
-        if ( not defined $param->{$type}{$addrOrSrv} ) {
-          my $createAddrOrSrv = "create" . ( ucfirst $type );
+        if (not defined $param->{$type}{$addrOrSrv}) {
+          my $createAddrOrSrv = "create" . (ucfirst $type);
           push @{$nameMap->{$type}}, $self->$createAddrOrSrv($addrOrSrv);
         }
 
@@ -248,14 +245,14 @@ sub checkAndCreateAddrOrSrvOrNat {
 # createNat 创建 NAT 函数入口，支持静态和动态 NAT
 #------------------------------------------------------------------------------
 sub createNat {
-  my ( $self, $param, $type ) = @_;
+  my ($self, $param, $type) = @_;
 
   # 初始化 dyNatInfo 标量
   my $dyNatInfo;
-  for my $natInfo ( values %{$param} ) {
+  for my $natInfo (values %{$param}) {
 
     # 情况1：静态NAT
-    if ( $natInfo->{"natInfo"}{"natType"} eq 'static' ) {
+    if ($natInfo->{"natInfo"}{"natType"} eq 'static') {
       $self->createStaticNat($natInfo);
     }
 
@@ -266,7 +263,7 @@ sub createNat {
   }
 
   # 如果存在 dyNatInfo 则开始创建动态 NAT
-  if ( defined $dyNatInfo ) {
+  if (defined $dyNatInfo) {
     $self->createDyNat($dyNatInfo);
   }
 } ## end sub createNat
@@ -275,10 +272,10 @@ sub createNat {
 # createStaticNat 创建静态NAT
 #------------------------------------------------------------------------------
 sub createStaticNat {
-  my ( $self, $natInfo ) = @_;
+  my ($self, $natInfo) = @_;
 
   use Mojo::Util qw(dumper);
-  say dumper $natInfo;
+  print dumper $natInfo;
 
   # 大网-外部实际可见IP
   my $natIp = $natInfo->{"natInfo"}{"natIp"};
@@ -291,31 +288,30 @@ sub createStaticNat {
 
   # 检查是否已定义地址名称
   my $searcher   = Firewall::Policy::Searcher::Topsec->new();
-  my $natIpName  = $searcher->getAnAddressName( $parser, undef, $natIp );
-  my $realIpName = $searcher->getAnAddressName( $parser, undef, $realIp );
+  my $natIpName  = $searcher->getAnAddressName($parser, undef, $natIp);
+  my $realIpName = $searcher->getAnAddressName($parser, undef, $realIp);
 
   # 判断是否已存在 natIpName realIpName
-  $natIpName = ( defined $natIpName ) ? $natIpName->[0] : $self->createAddress($natIp);
+  $natIpName = (defined $natIpName) ? $natIpName->[0] : $self->createAddress($natIp);
   $realIpName
-    = ( defined $realIpName )            ? $realIpName->[0]
+    = (defined $realIpName)              ? $realIpName->[0]
     : exists $self->{"address"}{$realIp} ? $self->{"address"}{$realIp}
     :                                      $self->createAddress($realIp);
 
   #综合 NAT 放行生成策略
   my $natDirection = $natInfo->{"natInfo"}{"natDirection"};
-  if ( defined $natDirection ) {
-    my ( $fromZone, $toZone )
-      = ( $self->{"searcherReportFwInfo"}{"fromZone"}, $self->{"searcherReportFwInfo"}{"toZone"} );
+  if (defined $natDirection) {
+    my ($fromZone, $toZone) = ($self->{"searcherReportFwInfo"}{"fromZone"}, $self->{"searcherReportFwInfo"}{"toZone"});
 
     # 情况1：目的地址NAT
-    if ( $natDirection eq 'destination' ) {
+    if ($natDirection eq 'destination') {
       my $zoneStr = "srcarea '$fromZone ' dstarea '$toZone '";
       my $cmdStr  = "nat policy add $zoneStr orig-dst '$natIpName ' trans-dst '$realIpName '";
       $self->addToCommandText($cmdStr);
     }
 
     #情况2：源地址NAT
-    elsif ( $natDirection eq 'source' ) {
+    elsif ($natDirection eq 'source') {
       my $zoneStr = "srcarea '$fromZone ' dstarea '$toZone '";
       my $cmdStr  = "nat policy add $zoneStr orig-src '$realIpName ' trans-src '$natIpName '";
       $self->addToCommandText($cmdStr);
@@ -327,42 +323,41 @@ sub createStaticNat {
 # createDyNat 动态生成 NAT策略
 #------------------------------------------------------------------------------
 sub createDyNat {
-  my ( $self, $param ) = @_;
+  my ($self, $param) = @_;
   use Mojo::Util qw(dumper);
-  say dumper $param;
+  print dumper $param;
 
   # 初始化相关变量
   my $parser   = $self->{"searcherReportFwInfo"}{"parser"};
   my $searcher = Firewall::Policy::Searcher::Topsec->new();
-  my ( $fromZone, $toZone )
-    = ( $self->{"searcherReportFwInfo"}{"fromZone"}, $self->{"searcherReportFwInfo"}{"toZone"} );
+  my ($fromZone, $toZone) = ($self->{"searcherReportFwInfo"}{"fromZone"}, $self->{"searcherReportFwInfo"}{"toZone"});
   my $zoneStr = "srcarea '$fromZone ' dstarea '$toZone '" || "";
 
   # 遍历 param
   my %natIpInfo;
-  for my $natDirection ( keys %{$param} ) {
-    for my $natInfo ( values %{$param->{$natDirection}} ) {
-      for my $nat ( values %{$natInfo} ) {
+  for my $natDirection (keys %{$param}) {
+    for my $natInfo (values %{$param->{$natDirection}}) {
+      for my $nat (values %{$natInfo}) {
         my $natIp = $nat->{"natInfo"}{"natIp"};
         push @{$natIpInfo{$natIp}{"realIp"}}, $nat->{"realIp"};
         $natIpInfo{$natIp}{"natOption"} = $nat->{"natInfo"}{"natOption"} || undef;
       }
 
       # 遍历 natIpInfo
-      for my $natIp ( keys %natIpInfo ) {
+      for my $natIp (keys %natIpInfo) {
         my $cmdStr = "nat policy add $zoneStr";
 
         # 计算大网地址对象
-        my $natIpName = $searcher->getAnAddressName( $parser, undef, $natIp );
-        $natIpName = ( defined $natIpName ) ? $natIpName->[0] : $self->createAddress($natIp);
+        my $natIpName = $searcher->getAnAddressName($parser, undef, $natIp);
+        $natIpName = (defined $natIpName) ? $natIpName->[0] : $self->createAddress($natIp);
 
         # 计算私网地址对象
         my $realIpStr = "'";
-        for my $realIp ( @{$natIpInfo{$natIp}{"realIp"}} ) {
-          my $realIpName = $searcher->getAnAddressName( $parser, undef, $realIp );
+        for my $realIp (@{$natIpInfo{$natIp}{"realIp"}}) {
+          my $realIpName = $searcher->getAnAddressName($parser, undef, $realIp);
 
           # 不存在则新增
-          if ( not defined $realIpName ) {
+          if (not defined $realIpName) {
 
             # 优先匹配已有信息
             $realIpName = $self->{"address"}{$realIp};
@@ -380,13 +375,13 @@ sub createDyNat {
         $realIpStr .= "'";
 
         # 情况1：源地址NAT
-        if ( $natDirection eq 'natSrc' ) {
+        if ($natDirection eq 'natSrc') {
           $cmdStr .= " orig-src '" . $realIpStr;
-          if ( defined $natIpInfo{$natIp}{"natOption"} and $natIpInfo{$natIp}{"natOption"} =~ /d/ ) {
+          if (defined $natIpInfo{$natIp}{"natOption"} and $natIpInfo{$natIp}{"natOption"} =~ /d/) {
             $cmdStr .= " orig-dst '";
-            for my $dstIp ( keys %{$self->{"searcherReportFwInfo"}{"dstMap"}} ) {
-              my $dstIpName = $searcher->getAnAddressName( $parser, undef, $dstIp );
-              if ( not defined $dstIpName ) {
+            for my $dstIp (keys %{$self->{"searcherReportFwInfo"}{"dstMap"}}) {
+              my $dstIpName = $searcher->getAnAddressName($parser, undef, $dstIp);
+              if (not defined $dstIpName) {
                 $dstIpName = $self->{"address"}{$dstIp};
                 $dstIpName = $self->createAddress($dstIp) if not defined $dstIpName;
               }
@@ -403,12 +398,12 @@ sub createDyNat {
         } ## end if ( $natDirection eq ...)
 
         # 情况2：目的地址NAT
-        elsif ( $natDirection eq 'natDst' ) {
-          if ( defined $natIpInfo{$natIp}{"natOption"} and $natIpInfo{$natIp}{"natOption"} =~ /s/ ) {
+        elsif ($natDirection eq 'natDst') {
+          if (defined $natIpInfo{$natIp}{"natOption"} and $natIpInfo{$natIp}{"natOption"} =~ /s/) {
             $cmdStr .= " orig-src '";
-            for my $srcIp ( keys %{$self->{"searcherReportFwInfo"}{"srcMap"}} ) {
-              my $srcIpName = $searcher->getAnAddressName( $parser, undef, $srcIp );
-              if ( not defined $srcIpName ) {
+            for my $srcIp (keys %{$self->{"searcherReportFwInfo"}{"srcMap"}}) {
+              my $srcIpName = $searcher->getAnAddressName($parser, undef, $srcIp);
+              if (not defined $srcIpName) {
                 $srcIpName = $self->{"address"}{$srcIp};
                 $srcIpName = $self->createAddress($srcIp) if not defined $srcIpName;
               }
@@ -432,7 +427,7 @@ sub createDyNat {
 # createSrc 创建源地址对象
 #------------------------------------------------------------------------------
 sub createSrc {
-  my ( $self, $addr ) = @_;
+  my ($self, $addr) = @_;
   return $self->createAddress($addr);
 }
 
@@ -440,7 +435,7 @@ sub createSrc {
 # createDst 创建目的地址对象
 #------------------------------------------------------------------------------
 sub createDst {
-  my ( $self, $addr ) = @_;
+  my ($self, $addr) = @_;
   return $self->createAddress($addr);
 }
 
@@ -448,7 +443,7 @@ sub createDst {
 # createSrv 创建服务端口对象
 #------------------------------------------------------------------------------
 sub createSrv {
-  my ( $self, $srv ) = @_;
+  my ($self, $srv) = @_;
   return $self->createService($srv);
 }
 
@@ -456,39 +451,39 @@ sub createSrv {
 # createAddress 具体实现创建地址对象
 #------------------------------------------------------------------------------
 sub createAddress {
-  my ( $self, $addr ) = @_;
+  my ($self, $addr) = @_;
 
   # 分割 子网/掩码 格式的IP
-  my ( $ip, $mask ) = split( '/', $addr );
+  my ($ip, $mask) = split('/', $addr);
   my $ipObj = Firewall::Utils::Ip->new();
 
   # 初始化相关变量
-  my ( $cmdStr, $addressName, $ipString, $ipMin, $ipMax );
+  my ($cmdStr, $addressName, $ipString, $ipMin, $ipMax);
 
   # 情况1：连续地址
-  if ( not defined $mask ) {
-    if ( $ip =~ /(\d+\.)(\d+\.)(\d+\.)(\d+)-(\d+)/ ) {
-      ( $ipMin, $ipMax ) = ( $1 . $2 . $3 . $4, $1 . $2 . $3 . $5 );
+  if (not defined $mask) {
+    if ($ip =~ /(\d+\.)(\d+\.)(\d+\.)(\d+)-(\d+)/) {
+      ($ipMin, $ipMax) = ($1 . $2 . $3 . $4, $1 . $2 . $3 . $5);
       $addressName = "range_$ip";
       $cmdStr      = "define range add name $addressName ip1 $ipMin ip2 $ipMax";
     }
   }
 
   # 情况2：主机地址
-  elsif ( $mask == 32 ) {
+  elsif ($mask == 32) {
     $ipString    = $ip;
     $addressName = "host_$ip";
     $cmdStr      = "define host add name $addressName ipaddr '$ip '";
   }
 
   # 情况3：掩码为0
-  elsif ( $mask == 0 ) {
+  elsif ($mask == 0) {
     return 'any';
   }
 
   # 情况4：将地址转换为子网格式
   else {
-    $ipString = $ipObj->getNetIpFromIpMask( $ip, $mask );
+    $ipString = $ipObj->getNetIpFromIpMask($ip, $mask);
     my $maskStr = $ipObj->changeMaskToIpForm($mask);
     $addressName = "net_$ipString/$mask";
     $cmdStr      = "define subnet add name $addressName ipaddr $ip mask $maskStr";
@@ -504,10 +499,10 @@ sub createAddress {
 # Firewall::Policy::Designer::Topsec 通用属性
 #------------------------------------------------------------------------------
 sub createService {
-  my ( $self, $srv ) = @_;
+  my ($self, $srv) = @_;
 
   # 分割服务端口为 协议、端口
-  my ( $protocol, $port ) = split( '/', $srv );
+  my ($protocol, $port) = split('/', $srv);
   $protocol = lc $protocol;
 
   # 跳过不支持的 protocol 字段
@@ -521,12 +516,12 @@ sub createService {
   $protoNum = $protocol if $protocol =~ /^\d+$/;
 
   #
-  my ( $cmdStr, $serviceName );
-  if ( $port =~ /^(?<portMin>\d+)\-(?<portMax>\d+)$/o ) {
+  my ($cmdStr, $serviceName);
+  if ($port =~ /^(?<portMin>\d+)\-(?<portMax>\d+)$/o) {
     $serviceName = lc($protocol) . "_" . $+{portMin} . "_" . $+{portMax};
     $cmdStr      = "define service add name $serviceName protocol $protoNum port $+{portMin} port2 $+{portMax}";
   }
-  elsif ( $port =~ /^\d+$/o ) {
+  elsif ($port =~ /^\d+$/o) {
     $serviceName = lc($protocol) . "_" . $port;
     $cmdStr      = "define service add name $serviceName protocol $protoNum port $port";
   }
